#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_ras_ext(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def show_raslog_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        input = ET.SubElement(show_raslog, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_input_number_of_latest_events(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        input = ET.SubElement(show_raslog, "input")
        number_of_latest_events = ET.SubElement(input, "number-of-latest-events")
        number_of_latest_events.text = kwargs.pop('number_of_latest_events')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        rbridge_id = ET.SubElement(show_all_raslog, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_number_of_entries(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        number_of_entries = ET.SubElement(show_all_raslog, "number-of-entries")
        number_of_entries.text = kwargs.pop('number_of_entries')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_index(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        index = ET.SubElement(raslog_entries, "index")
        index.text = kwargs.pop('index')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_message_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        message_id = ET.SubElement(raslog_entries, "message-id")
        message_id.text = kwargs.pop('message_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_date_and_time_info(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        date_and_time_info = ET.SubElement(raslog_entries, "date-and-time-info")
        date_and_time_info.text = kwargs.pop('date_and_time_info')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_severity(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        severity = ET.SubElement(raslog_entries, "severity")
        severity.text = kwargs.pop('severity')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_repeat_count(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        repeat_count = ET.SubElement(raslog_entries, "repeat-count")
        repeat_count.text = kwargs.pop('repeat_count')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_message(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        message = ET.SubElement(raslog_entries, "message")
        message.text = kwargs.pop('message')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_message_flag(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        message_flag = ET.SubElement(raslog_entries, "message-flag")
        message_flag.text = kwargs.pop('message_flag')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_log_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        log_type = ET.SubElement(raslog_entries, "log-type")
        log_type.text = kwargs.pop('log_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_switch_or_chassis_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        switch_or_chassis_name = ET.SubElement(raslog_entries, "switch-or-chassis-name")
        switch_or_chassis_name.text = kwargs.pop('switch_or_chassis_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_cmd_status_error_msg(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        cmd_status_error_msg = ET.SubElement(output, "cmd-status-error-msg")
        cmd_status_error_msg.text = kwargs.pop('cmd_status_error_msg')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_support_save_status_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_support_save_status = ET.Element("show_support_save_status")
        config = show_support_save_status
        input = ET.SubElement(show_support_save_status, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_support_save_status_output_show_support_save_status_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_support_save_status = ET.Element("show_support_save_status")
        config = show_support_save_status
        output = ET.SubElement(show_support_save_status, "output")
        show_support_save_status = ET.SubElement(output, "show-support-save-status")
        rbridge_id = ET.SubElement(show_support_save_status, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_support_save_status_output_show_support_save_status_status(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_support_save_status = ET.Element("show_support_save_status")
        config = show_support_save_status
        output = ET.SubElement(show_support_save_status, "output")
        show_support_save_status = ET.SubElement(output, "show-support-save-status")
        status = ET.SubElement(show_support_save_status, "status")
        status.text = kwargs.pop('status')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_support_save_status_output_show_support_save_status_message(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_support_save_status = ET.Element("show_support_save_status")
        config = show_support_save_status
        output = ET.SubElement(show_support_save_status, "output")
        show_support_save_status = ET.SubElement(output, "show-support-save-status")
        message = ET.SubElement(show_support_save_status, "message")
        message.text = kwargs.pop('message')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_support_save_status_output_show_support_save_status_percentage_of_completion(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_support_save_status = ET.Element("show_support_save_status")
        config = show_support_save_status
        output = ET.SubElement(show_support_save_status, "output")
        show_support_save_status = ET.SubElement(output, "show-support-save-status")
        percentage_of_completion = ET.SubElement(show_support_save_status, "percentage-of-completion")
        percentage_of_completion.text = kwargs.pop('percentage_of_completion')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_info_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_info = ET.Element("show_system_info")
        config = show_system_info
        input = ET.SubElement(show_system_info, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_info_output_show_system_info_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_info = ET.Element("show_system_info")
        config = show_system_info
        output = ET.SubElement(show_system_info, "output")
        show_system_info = ET.SubElement(output, "show-system-info")
        rbridge_id = ET.SubElement(show_system_info, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_info_output_show_system_info_stack_mac(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_info = ET.Element("show_system_info")
        config = show_system_info
        output = ET.SubElement(show_system_info, "output")
        show_system_info = ET.SubElement(output, "show-system-info")
        stack_mac = ET.SubElement(show_system_info, "stack-mac")
        stack_mac.text = kwargs.pop('stack_mac')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        input = ET.SubElement(show_raslog, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_input_number_of_latest_events(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        input = ET.SubElement(show_raslog, "input")
        number_of_latest_events = ET.SubElement(input, "number-of-latest-events")
        number_of_latest_events.text = kwargs.pop('number_of_latest_events')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        rbridge_id = ET.SubElement(show_all_raslog, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_number_of_entries(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        number_of_entries = ET.SubElement(show_all_raslog, "number-of-entries")
        number_of_entries.text = kwargs.pop('number_of_entries')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_index(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        index = ET.SubElement(raslog_entries, "index")
        index.text = kwargs.pop('index')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_message_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        message_id = ET.SubElement(raslog_entries, "message-id")
        message_id.text = kwargs.pop('message_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_date_and_time_info(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        date_and_time_info = ET.SubElement(raslog_entries, "date-and-time-info")
        date_and_time_info.text = kwargs.pop('date_and_time_info')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_severity(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        severity = ET.SubElement(raslog_entries, "severity")
        severity.text = kwargs.pop('severity')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_repeat_count(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        repeat_count = ET.SubElement(raslog_entries, "repeat-count")
        repeat_count.text = kwargs.pop('repeat_count')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_message(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        message = ET.SubElement(raslog_entries, "message")
        message.text = kwargs.pop('message')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_message_flag(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        message_flag = ET.SubElement(raslog_entries, "message-flag")
        message_flag.text = kwargs.pop('message_flag')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_log_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        log_type = ET.SubElement(raslog_entries, "log-type")
        log_type.text = kwargs.pop('log_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_show_all_raslog_raslog_entries_switch_or_chassis_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        show_all_raslog = ET.SubElement(output, "show-all-raslog")
        raslog_entries = ET.SubElement(show_all_raslog, "raslog-entries")
        switch_or_chassis_name = ET.SubElement(raslog_entries, "switch-or-chassis-name")
        switch_or_chassis_name.text = kwargs.pop('switch_or_chassis_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_raslog_output_cmd_status_error_msg(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_raslog = ET.Element("show_raslog")
        config = show_raslog
        output = ET.SubElement(show_raslog, "output")
        cmd_status_error_msg = ET.SubElement(output, "cmd-status-error-msg")
        cmd_status_error_msg.text = kwargs.pop('cmd_status_error_msg')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_support_save_status_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_support_save_status = ET.Element("show_support_save_status")
        config = show_support_save_status
        input = ET.SubElement(show_support_save_status, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_support_save_status_output_show_support_save_status_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_support_save_status = ET.Element("show_support_save_status")
        config = show_support_save_status
        output = ET.SubElement(show_support_save_status, "output")
        show_support_save_status = ET.SubElement(output, "show-support-save-status")
        rbridge_id = ET.SubElement(show_support_save_status, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_support_save_status_output_show_support_save_status_status(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_support_save_status = ET.Element("show_support_save_status")
        config = show_support_save_status
        output = ET.SubElement(show_support_save_status, "output")
        show_support_save_status = ET.SubElement(output, "show-support-save-status")
        status = ET.SubElement(show_support_save_status, "status")
        status.text = kwargs.pop('status')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_support_save_status_output_show_support_save_status_message(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_support_save_status = ET.Element("show_support_save_status")
        config = show_support_save_status
        output = ET.SubElement(show_support_save_status, "output")
        show_support_save_status = ET.SubElement(output, "show-support-save-status")
        message = ET.SubElement(show_support_save_status, "message")
        message.text = kwargs.pop('message')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_support_save_status_output_show_support_save_status_percentage_of_completion(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_support_save_status = ET.Element("show_support_save_status")
        config = show_support_save_status
        output = ET.SubElement(show_support_save_status, "output")
        show_support_save_status = ET.SubElement(output, "show-support-save-status")
        percentage_of_completion = ET.SubElement(show_support_save_status, "percentage-of-completion")
        percentage_of_completion.text = kwargs.pop('percentage_of_completion')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_info_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_info = ET.Element("show_system_info")
        config = show_system_info
        input = ET.SubElement(show_system_info, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_info_output_show_system_info_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_info = ET.Element("show_system_info")
        config = show_system_info
        output = ET.SubElement(show_system_info, "output")
        show_system_info = ET.SubElement(output, "show-system-info")
        rbridge_id = ET.SubElement(show_system_info, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_info_output_show_system_info_stack_mac(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_info = ET.Element("show_system_info")
        config = show_system_info
        output = ET.SubElement(show_system_info, "output")
        show_system_info = ET.SubElement(output, "show-system-info")
        stack_mac = ET.SubElement(show_system_info, "stack-mac")
        stack_mac.text = kwargs.pop('stack_mac')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_event_handler(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def event_handler_event_handler_list_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        event_handler = ET.SubElement(config, "event-handler", xmlns="urn:brocade.com:mgmt:brocade-event-handler")
        event_handler_list = ET.SubElement(event_handler, "event-handler-list")
        name = ET.SubElement(event_handler_list, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def event_handler_event_handler_list_trigger_trigger_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        event_handler = ET.SubElement(config, "event-handler", xmlns="urn:brocade.com:mgmt:brocade-event-handler")
        event_handler_list = ET.SubElement(event_handler, "event-handler-list")
        name_key = ET.SubElement(event_handler_list, "name")
        name_key.text = kwargs.pop('name')
        trigger = ET.SubElement(event_handler_list, "trigger")
        trigger_id = ET.SubElement(trigger, "trigger-id")
        trigger_id.text = kwargs.pop('trigger_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def event_handler_event_handler_list_trigger_trigger_choice_vcs_vcs(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        event_handler = ET.SubElement(config, "event-handler", xmlns="urn:brocade.com:mgmt:brocade-event-handler")
        event_handler_list = ET.SubElement(event_handler, "event-handler-list")
        name_key = ET.SubElement(event_handler_list, "name")
        name_key.text = kwargs.pop('name')
        trigger = ET.SubElement(event_handler_list, "trigger")
        trigger_id_key = ET.SubElement(trigger, "trigger-id")
        trigger_id_key.text = kwargs.pop('trigger_id')
        trigger_choice = ET.SubElement(trigger, "trigger-choice")
        vcs = ET.SubElement(trigger_choice, "vcs")
        vcs = ET.SubElement(vcs, "vcs")
        vcs.text = kwargs.pop('vcs')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def event_handler_event_handler_list_trigger_trigger_choice_raslog_raslog(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        event_handler = ET.SubElement(config, "event-handler", xmlns="urn:brocade.com:mgmt:brocade-event-handler")
        event_handler_list = ET.SubElement(event_handler, "event-handler-list")
        name_key = ET.SubElement(event_handler_list, "name")
        name_key.text = kwargs.pop('name')
        trigger = ET.SubElement(event_handler_list, "trigger")
        trigger_id_key = ET.SubElement(trigger, "trigger-id")
        trigger_id_key.text = kwargs.pop('trigger_id')
        trigger_choice = ET.SubElement(trigger, "trigger-choice")
        raslog = ET.SubElement(trigger_choice, "raslog")
        raslog = ET.SubElement(raslog, "raslog")
        raslog.text = kwargs.pop('raslog')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def event_handler_event_handler_list_action_action_choice_python_script_python_script(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        event_handler = ET.SubElement(config, "event-handler", xmlns="urn:brocade.com:mgmt:brocade-event-handler")
        event_handler_list = ET.SubElement(event_handler, "event-handler-list")
        name_key = ET.SubElement(event_handler_list, "name")
        name_key.text = kwargs.pop('name')
        action = ET.SubElement(event_handler_list, "action")
        action_choice = ET.SubElement(action, "action-choice")
        python_script = ET.SubElement(action_choice, "python-script")
        python_script = ET.SubElement(python_script, "python-script")
        python_script.text = kwargs.pop('python_script')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def event_handler_event_handler_list_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        event_handler = ET.SubElement(config, "event-handler", xmlns="urn:brocade.com:mgmt:brocade-event-handler")
        event_handler_list = ET.SubElement(event_handler, "event-handler-list")
        name = ET.SubElement(event_handler_list, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def event_handler_event_handler_list_trigger_trigger_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        event_handler = ET.SubElement(config, "event-handler", xmlns="urn:brocade.com:mgmt:brocade-event-handler")
        event_handler_list = ET.SubElement(event_handler, "event-handler-list")
        name_key = ET.SubElement(event_handler_list, "name")
        name_key.text = kwargs.pop('name')
        trigger = ET.SubElement(event_handler_list, "trigger")
        trigger_id = ET.SubElement(trigger, "trigger-id")
        trigger_id.text = kwargs.pop('trigger_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def event_handler_event_handler_list_trigger_trigger_choice_vcs_vcs(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        event_handler = ET.SubElement(config, "event-handler", xmlns="urn:brocade.com:mgmt:brocade-event-handler")
        event_handler_list = ET.SubElement(event_handler, "event-handler-list")
        name_key = ET.SubElement(event_handler_list, "name")
        name_key.text = kwargs.pop('name')
        trigger = ET.SubElement(event_handler_list, "trigger")
        trigger_id_key = ET.SubElement(trigger, "trigger-id")
        trigger_id_key.text = kwargs.pop('trigger_id')
        trigger_choice = ET.SubElement(trigger, "trigger-choice")
        vcs = ET.SubElement(trigger_choice, "vcs")
        vcs = ET.SubElement(vcs, "vcs")
        vcs.text = kwargs.pop('vcs')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def event_handler_event_handler_list_trigger_trigger_choice_raslog_raslog(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        event_handler = ET.SubElement(config, "event-handler", xmlns="urn:brocade.com:mgmt:brocade-event-handler")
        event_handler_list = ET.SubElement(event_handler, "event-handler-list")
        name_key = ET.SubElement(event_handler_list, "name")
        name_key.text = kwargs.pop('name')
        trigger = ET.SubElement(event_handler_list, "trigger")
        trigger_id_key = ET.SubElement(trigger, "trigger-id")
        trigger_id_key.text = kwargs.pop('trigger_id')
        trigger_choice = ET.SubElement(trigger, "trigger-choice")
        raslog = ET.SubElement(trigger_choice, "raslog")
        raslog = ET.SubElement(raslog, "raslog")
        raslog.text = kwargs.pop('raslog')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def event_handler_event_handler_list_action_action_choice_python_script_python_script(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        event_handler = ET.SubElement(config, "event-handler", xmlns="urn:brocade.com:mgmt:brocade-event-handler")
        event_handler_list = ET.SubElement(event_handler, "event-handler-list")
        name_key = ET.SubElement(event_handler_list, "name")
        name_key.text = kwargs.pop('name')
        action = ET.SubElement(event_handler_list, "action")
        action_choice = ET.SubElement(action, "action-choice")
        python_script = ET.SubElement(action_choice, "python-script")
        python_script = ET.SubElement(python_script, "python-script")
        python_script.text = kwargs.pop('python_script')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_preprovision(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def preprovision_rbridge_id_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        preprovision = ET.SubElement(config, "preprovision", xmlns="urn:brocade.com:mgmt:brocade-preprovision")
        rbridge_id = ET.SubElement(preprovision, "rbridge-id")
        wwn_key = ET.SubElement(rbridge_id, "wwn")
        wwn_key.text = kwargs.pop('wwn')
        rbridge_id = ET.SubElement(rbridge_id, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def preprovision_rbridge_id_wwn(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        preprovision = ET.SubElement(config, "preprovision", xmlns="urn:brocade.com:mgmt:brocade-preprovision")
        rbridge_id = ET.SubElement(preprovision, "rbridge-id")
        rbridge_id_key = ET.SubElement(rbridge_id, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        wwn = ET.SubElement(rbridge_id, "wwn")
        wwn.text = kwargs.pop('wwn')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_bare_metal_state_output_bare_metal_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_bare_metal_state = ET.Element("show_bare_metal_state")
        config = show_bare_metal_state
        output = ET.SubElement(show_bare_metal_state, "output")
        bare_metal_state = ET.SubElement(output, "bare-metal-state")
        bare_metal_state.text = kwargs.pop('bare_metal_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def preprovision_rbridge_id_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        preprovision = ET.SubElement(config, "preprovision", xmlns="urn:brocade.com:mgmt:brocade-preprovision")
        rbridge_id = ET.SubElement(preprovision, "rbridge-id")
        wwn_key = ET.SubElement(rbridge_id, "wwn")
        wwn_key.text = kwargs.pop('wwn')
        rbridge_id = ET.SubElement(rbridge_id, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def preprovision_rbridge_id_wwn(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        preprovision = ET.SubElement(config, "preprovision", xmlns="urn:brocade.com:mgmt:brocade-preprovision")
        rbridge_id = ET.SubElement(preprovision, "rbridge-id")
        rbridge_id_key = ET.SubElement(rbridge_id, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        wwn = ET.SubElement(rbridge_id, "wwn")
        wwn.text = kwargs.pop('wwn')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_bare_metal_state_output_bare_metal_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_bare_metal_state = ET.Element("show_bare_metal_state")
        config = show_bare_metal_state
        output = ET.SubElement(show_bare_metal_state, "output")
        bare_metal_state = ET.SubElement(output, "bare-metal-state")
        bare_metal_state.text = kwargs.pop('bare_metal_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""


import unittest
import xml.etree.ElementTree as ET
import pynos.versions.base.system as system
import pynos.utilities


class TestSystem(unittest.TestCase):
    """
    System unit tests. Compare expected XML to generated XML.
    """
    def setUp(self):
        self.system = system.System(pynos.utilities.return_xml)
        self.namespace = 'urn:brocade.com:mgmt:brocade-system'
        self.netconf_namespace = 'urn:ietf:params:xml:ns:netconf:base:1.0'
        self.rbridge_namespace = 'urn:brocade.com:mgmt:brocade-rbridge'

    def uptime_xml(self, *args, **kwargs):
        message_id = 'urn:uuid:528cdf32-2e86-11e5-bb27-080027b782e4'
        uptime_xml = '<ns0:rpc-reply xmlns:ns0="{0}" '\
                     'xmlns:ns1="{1}" message-id="{2}">'\
                     '<ns1:show-system-uptime><ns1:rbridge-id>226'\
                     '</ns1:rbridge-id><ns1:days>1</ns1:days><ns1:hours>21'\
                     '</ns1:hours><ns1:minutes>59</ns1:minutes><ns1:seconds>'\
                     '57</ns1:seconds></ns1:show-system-uptime>'\
                     '</ns0:rpc-reply>'.format(self.netconf_namespace,
                                               self.namespace,
                                               message_id)
        return ET.fromstring(uptime_xml)

    def test_uptime(self):
        expected = {'days': '1',
                    'hours': '21',
                    'minutes': '59',
                    'seconds': '57'}
        self.system._callback = self.uptime_xml
        results = self.system.uptime
        self.assertDictEqual(expected, results)

    def test_router_id(self):
        rtm_namespace = 'urn:brocade.com:mgmt:brocade-rtm'
        expected = '<config><rbridge-id xmlns="{0}"><rbridge-id>2'\
                   '</rbridge-id><ip><rtm-config xmlns="{1}"><router-id>'\
                   '10.10.10.10</router-id></rtm-config></ip></rbridge-id>'\
                   '</config>'.format(self.rbridge_namespace, rtm_namespace)
        result = self.system.router_id(rbridge_id='2', router_id='10.10.10.10')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_router_id_exception(self):
        with self.assertRaises(KeyError):
            self.system.router_id()



#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_lag(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def get_port_channel_detail_input_last_aggregator_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        input = ET.SubElement(get_port_channel_detail, "input")
        last_aggregator_id = ET.SubElement(input, "last-aggregator-id")
        last_aggregator_id.text = kwargs.pop('last_aggregator_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggregator_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggregator_id = ET.SubElement(lacp, "aggregator-id")
        aggregator_id.text = kwargs.pop('aggregator_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggregator_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggregator_type = ET.SubElement(lacp, "aggregator-type")
        aggregator_type.text = kwargs.pop('aggregator_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_isvlag(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        isvlag = ET.SubElement(lacp, "isvlag")
        isvlag.text = kwargs.pop('isvlag')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggregator_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggregator_mode = ET.SubElement(lacp, "aggregator-mode")
        aggregator_mode.text = kwargs.pop('aggregator_mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_admin_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        admin_key = ET.SubElement(lacp, "admin-key")
        admin_key.text = kwargs.pop('admin_key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_oper_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        oper_key = ET.SubElement(lacp, "oper-key")
        oper_key.text = kwargs.pop('oper_key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_actor_system_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_system_id = ET.SubElement(lacp, "actor-system-id")
        actor_system_id.text = kwargs.pop('actor_system_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_partner_system_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_system_id = ET.SubElement(lacp, "partner-system-id")
        partner_system_id.text = kwargs.pop('partner_system_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_system_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        system_priority = ET.SubElement(lacp, "system-priority")
        system_priority.text = kwargs.pop('system_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_partner_oper_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_oper_priority = ET.SubElement(lacp, "partner-oper-priority")
        partner_oper_priority.text = kwargs.pop('partner_oper_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_rx_link_count(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        rx_link_count = ET.SubElement(lacp, "rx-link-count")
        rx_link_count.text = kwargs.pop('rx_link_count')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_tx_link_count(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        tx_link_count = ET.SubElement(lacp, "tx-link-count")
        tx_link_count.text = kwargs.pop('tx_link_count')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_individual_agg(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        individual_agg = ET.SubElement(lacp, "individual-agg")
        individual_agg.text = kwargs.pop('individual_agg')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_ready_agg(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        ready_agg = ET.SubElement(lacp, "ready-agg")
        ready_agg.text = kwargs.pop('ready_agg')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_partner_oper_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_oper_key = ET.SubElement(lacp, "partner-oper-key")
        partner_oper_key.text = kwargs.pop('partner_oper_key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggr_member_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggr_member = ET.SubElement(lacp, "aggr-member")
        rbridge_id = ET.SubElement(aggr_member, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggr_member_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggr_member = ET.SubElement(lacp, "aggr-member")
        interface_type = ET.SubElement(aggr_member, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggr_member_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggr_member = ET.SubElement(lacp, "aggr-member")
        interface_name = ET.SubElement(aggr_member, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggr_member_actor_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggr_member = ET.SubElement(lacp, "aggr-member")
        actor_port = ET.SubElement(aggr_member, "actor-port")
        actor_port.text = kwargs.pop('actor_port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggr_member_sync(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggr_member = ET.SubElement(lacp, "aggr-member")
        sync = ET.SubElement(aggr_member, "sync")
        sync.text = kwargs.pop('sync')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_has_more(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        has_more = ET.SubElement(output, "has-more")
        has_more.text = kwargs.pop('has_more')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_input_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        input = ET.SubElement(get_portchannel_info_by_intf, "input")
        interface_type = ET.SubElement(input, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_input_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        input = ET.SubElement(get_portchannel_info_by_intf, "input")
        interface_name = ET.SubElement(input, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        interface_type = ET.SubElement(lacp, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        interface_name = ET.SubElement(lacp, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_port = ET.SubElement(lacp, "actor-port")
        actor_port.text = kwargs.pop('actor_port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_admin_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        admin_key = ET.SubElement(lacp, "admin-key")
        admin_key.text = kwargs.pop('admin_key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_oper_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        oper_key = ET.SubElement(lacp, "oper-key")
        oper_key.text = kwargs.pop('oper_key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_system_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_system_id = ET.SubElement(lacp, "actor-system-id")
        actor_system_id.text = kwargs.pop('actor_system_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_system_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_system_id = ET.SubElement(lacp, "partner-system-id")
        partner_system_id.text = kwargs.pop('partner_system_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_system_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        system_priority = ET.SubElement(lacp, "system-priority")
        system_priority.text = kwargs.pop('system_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_oper_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_oper_priority = ET.SubElement(lacp, "partner-oper-priority")
        partner_oper_priority.text = kwargs.pop('partner_oper_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_priority = ET.SubElement(lacp, "actor-priority")
        actor_priority.text = kwargs.pop('actor_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_receive_machine_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        receive_machine_state = ET.SubElement(lacp, "receive-machine-state")
        receive_machine_state.text = kwargs.pop('receive_machine_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_periodic_transmission_machine_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        periodic_transmission_machine_state = ET.SubElement(lacp, "periodic-transmission-machine-state")
        periodic_transmission_machine_state.text = kwargs.pop('periodic_transmission_machine_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_mux_machine_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        mux_machine_state = ET.SubElement(lacp, "mux-machine-state")
        mux_machine_state.text = kwargs.pop('mux_machine_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_admin_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        admin_state = ET.SubElement(lacp, "admin-state")
        admin_state.text = kwargs.pop('admin_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_oper_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        oper_state = ET.SubElement(lacp, "oper-state")
        oper_state.text = kwargs.pop('oper_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_oper_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_oper_state = ET.SubElement(lacp, "partner-oper-state")
        partner_oper_state.text = kwargs.pop('partner_oper_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_oper_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_oper_port = ET.SubElement(lacp, "partner-oper-port")
        partner_oper_port.text = kwargs.pop('partner_oper_port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_chip_number(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_chip_number = ET.SubElement(lacp, "actor-chip-number")
        actor_chip_number.text = kwargs.pop('actor_chip_number')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_max_deskew(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_max_deskew = ET.SubElement(lacp, "actor-max-deskew")
        actor_max_deskew.text = kwargs.pop('actor_max_deskew')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_chip_number(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_chip_number = ET.SubElement(lacp, "partner-chip-number")
        partner_chip_number.text = kwargs.pop('partner_chip_number')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_max_deskew(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_max_deskew = ET.SubElement(lacp, "partner-max-deskew")
        partner_max_deskew.text = kwargs.pop('partner_max_deskew')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_brcd_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_brcd_state = ET.SubElement(lacp, "actor-brcd-state")
        actor_brcd_state.text = kwargs.pop('actor_brcd_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_brcd_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_brcd_state = ET.SubElement(lacp, "partner-brcd-state")
        partner_brcd_state.text = kwargs.pop('partner_brcd_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def port_channel_redundancy_group_group_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        port_channel_redundancy_group = ET.SubElement(config, "port-channel-redundancy-group", xmlns="urn:brocade.com:mgmt:brocade-lag")
        group_id = ET.SubElement(port_channel_redundancy_group, "group-id")
        group_id.text = kwargs.pop('group_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def port_channel_redundancy_group_port_channel_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        port_channel_redundancy_group = ET.SubElement(config, "port-channel-redundancy-group", xmlns="urn:brocade.com:mgmt:brocade-lag")
        group_id_key = ET.SubElement(port_channel_redundancy_group, "group-id")
        group_id_key.text = kwargs.pop('group_id')
        port_channel = ET.SubElement(port_channel_redundancy_group, "port-channel")
        name = ET.SubElement(port_channel, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def port_channel_redundancy_group_port_channel_port_channel_active(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        port_channel_redundancy_group = ET.SubElement(config, "port-channel-redundancy-group", xmlns="urn:brocade.com:mgmt:brocade-lag")
        group_id_key = ET.SubElement(port_channel_redundancy_group, "group-id")
        group_id_key.text = kwargs.pop('group_id')
        port_channel = ET.SubElement(port_channel_redundancy_group, "port-channel")
        name_key = ET.SubElement(port_channel, "name")
        name_key.text = kwargs.pop('name')
        port_channel_active = ET.SubElement(port_channel, "port-channel-active")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def port_channel_redundancy_group_activate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        port_channel_redundancy_group = ET.SubElement(config, "port-channel-redundancy-group", xmlns="urn:brocade.com:mgmt:brocade-lag")
        group_id_key = ET.SubElement(port_channel_redundancy_group, "group-id")
        group_id_key.text = kwargs.pop('group_id')
        activate = ET.SubElement(port_channel_redundancy_group, "activate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_input_last_aggregator_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        input = ET.SubElement(get_port_channel_detail, "input")
        last_aggregator_id = ET.SubElement(input, "last-aggregator-id")
        last_aggregator_id.text = kwargs.pop('last_aggregator_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggregator_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggregator_id = ET.SubElement(lacp, "aggregator-id")
        aggregator_id.text = kwargs.pop('aggregator_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggregator_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggregator_type = ET.SubElement(lacp, "aggregator-type")
        aggregator_type.text = kwargs.pop('aggregator_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_isvlag(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        isvlag = ET.SubElement(lacp, "isvlag")
        isvlag.text = kwargs.pop('isvlag')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggregator_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggregator_mode = ET.SubElement(lacp, "aggregator-mode")
        aggregator_mode.text = kwargs.pop('aggregator_mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_admin_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        admin_key = ET.SubElement(lacp, "admin-key")
        admin_key.text = kwargs.pop('admin_key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_oper_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        oper_key = ET.SubElement(lacp, "oper-key")
        oper_key.text = kwargs.pop('oper_key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_actor_system_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_system_id = ET.SubElement(lacp, "actor-system-id")
        actor_system_id.text = kwargs.pop('actor_system_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_partner_system_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_system_id = ET.SubElement(lacp, "partner-system-id")
        partner_system_id.text = kwargs.pop('partner_system_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_system_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        system_priority = ET.SubElement(lacp, "system-priority")
        system_priority.text = kwargs.pop('system_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_partner_oper_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_oper_priority = ET.SubElement(lacp, "partner-oper-priority")
        partner_oper_priority.text = kwargs.pop('partner_oper_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_rx_link_count(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        rx_link_count = ET.SubElement(lacp, "rx-link-count")
        rx_link_count.text = kwargs.pop('rx_link_count')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_tx_link_count(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        tx_link_count = ET.SubElement(lacp, "tx-link-count")
        tx_link_count.text = kwargs.pop('tx_link_count')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_individual_agg(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        individual_agg = ET.SubElement(lacp, "individual-agg")
        individual_agg.text = kwargs.pop('individual_agg')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_ready_agg(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        ready_agg = ET.SubElement(lacp, "ready-agg")
        ready_agg.text = kwargs.pop('ready_agg')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_partner_oper_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_oper_key = ET.SubElement(lacp, "partner-oper-key")
        partner_oper_key.text = kwargs.pop('partner_oper_key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggr_member_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggr_member = ET.SubElement(lacp, "aggr-member")
        rbridge_id = ET.SubElement(aggr_member, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggr_member_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggr_member = ET.SubElement(lacp, "aggr-member")
        interface_type = ET.SubElement(aggr_member, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggr_member_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggr_member = ET.SubElement(lacp, "aggr-member")
        interface_name = ET.SubElement(aggr_member, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggr_member_actor_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggr_member = ET.SubElement(lacp, "aggr-member")
        actor_port = ET.SubElement(aggr_member, "actor-port")
        actor_port.text = kwargs.pop('actor_port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_lacp_aggr_member_sync(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        lacp = ET.SubElement(output, "lacp")
        aggr_member = ET.SubElement(lacp, "aggr-member")
        sync = ET.SubElement(aggr_member, "sync")
        sync.text = kwargs.pop('sync')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_port_channel_detail_output_has_more(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_port_channel_detail = ET.Element("get_port_channel_detail")
        config = get_port_channel_detail
        output = ET.SubElement(get_port_channel_detail, "output")
        has_more = ET.SubElement(output, "has-more")
        has_more.text = kwargs.pop('has_more')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_input_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        input = ET.SubElement(get_portchannel_info_by_intf, "input")
        interface_type = ET.SubElement(input, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_input_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        input = ET.SubElement(get_portchannel_info_by_intf, "input")
        interface_name = ET.SubElement(input, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        interface_type = ET.SubElement(lacp, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        interface_name = ET.SubElement(lacp, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_port = ET.SubElement(lacp, "actor-port")
        actor_port.text = kwargs.pop('actor_port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_admin_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        admin_key = ET.SubElement(lacp, "admin-key")
        admin_key.text = kwargs.pop('admin_key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_oper_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        oper_key = ET.SubElement(lacp, "oper-key")
        oper_key.text = kwargs.pop('oper_key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_system_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_system_id = ET.SubElement(lacp, "actor-system-id")
        actor_system_id.text = kwargs.pop('actor_system_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_system_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_system_id = ET.SubElement(lacp, "partner-system-id")
        partner_system_id.text = kwargs.pop('partner_system_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_system_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        system_priority = ET.SubElement(lacp, "system-priority")
        system_priority.text = kwargs.pop('system_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_oper_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_oper_priority = ET.SubElement(lacp, "partner-oper-priority")
        partner_oper_priority.text = kwargs.pop('partner_oper_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_priority = ET.SubElement(lacp, "actor-priority")
        actor_priority.text = kwargs.pop('actor_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_receive_machine_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        receive_machine_state = ET.SubElement(lacp, "receive-machine-state")
        receive_machine_state.text = kwargs.pop('receive_machine_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_periodic_transmission_machine_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        periodic_transmission_machine_state = ET.SubElement(lacp, "periodic-transmission-machine-state")
        periodic_transmission_machine_state.text = kwargs.pop('periodic_transmission_machine_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_mux_machine_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        mux_machine_state = ET.SubElement(lacp, "mux-machine-state")
        mux_machine_state.text = kwargs.pop('mux_machine_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_admin_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        admin_state = ET.SubElement(lacp, "admin-state")
        admin_state.text = kwargs.pop('admin_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_oper_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        oper_state = ET.SubElement(lacp, "oper-state")
        oper_state.text = kwargs.pop('oper_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_oper_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_oper_state = ET.SubElement(lacp, "partner-oper-state")
        partner_oper_state.text = kwargs.pop('partner_oper_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_oper_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_oper_port = ET.SubElement(lacp, "partner-oper-port")
        partner_oper_port.text = kwargs.pop('partner_oper_port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_chip_number(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_chip_number = ET.SubElement(lacp, "actor-chip-number")
        actor_chip_number.text = kwargs.pop('actor_chip_number')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_max_deskew(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_max_deskew = ET.SubElement(lacp, "actor-max-deskew")
        actor_max_deskew.text = kwargs.pop('actor_max_deskew')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_chip_number(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_chip_number = ET.SubElement(lacp, "partner-chip-number")
        partner_chip_number.text = kwargs.pop('partner_chip_number')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_max_deskew(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_max_deskew = ET.SubElement(lacp, "partner-max-deskew")
        partner_max_deskew.text = kwargs.pop('partner_max_deskew')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_actor_brcd_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        actor_brcd_state = ET.SubElement(lacp, "actor-brcd-state")
        actor_brcd_state.text = kwargs.pop('actor_brcd_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_portchannel_info_by_intf_output_lacp_partner_brcd_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_portchannel_info_by_intf = ET.Element("get_portchannel_info_by_intf")
        config = get_portchannel_info_by_intf
        output = ET.SubElement(get_portchannel_info_by_intf, "output")
        lacp = ET.SubElement(output, "lacp")
        partner_brcd_state = ET.SubElement(lacp, "partner-brcd-state")
        partner_brcd_state.text = kwargs.pop('partner_brcd_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def port_channel_redundancy_group_group_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        port_channel_redundancy_group = ET.SubElement(config, "port-channel-redundancy-group", xmlns="urn:brocade.com:mgmt:brocade-lag")
        group_id = ET.SubElement(port_channel_redundancy_group, "group-id")
        group_id.text = kwargs.pop('group_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def port_channel_redundancy_group_port_channel_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        port_channel_redundancy_group = ET.SubElement(config, "port-channel-redundancy-group", xmlns="urn:brocade.com:mgmt:brocade-lag")
        group_id_key = ET.SubElement(port_channel_redundancy_group, "group-id")
        group_id_key.text = kwargs.pop('group_id')
        port_channel = ET.SubElement(port_channel_redundancy_group, "port-channel")
        name = ET.SubElement(port_channel, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def port_channel_redundancy_group_port_channel_port_channel_active(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        port_channel_redundancy_group = ET.SubElement(config, "port-channel-redundancy-group", xmlns="urn:brocade.com:mgmt:brocade-lag")
        group_id_key = ET.SubElement(port_channel_redundancy_group, "group-id")
        group_id_key.text = kwargs.pop('group_id')
        port_channel = ET.SubElement(port_channel_redundancy_group, "port-channel")
        name_key = ET.SubElement(port_channel, "name")
        name_key.text = kwargs.pop('name')
        port_channel_active = ET.SubElement(port_channel, "port-channel-active")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def port_channel_redundancy_group_activate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        port_channel_redundancy_group = ET.SubElement(config, "port-channel-redundancy-group", xmlns="urn:brocade.com:mgmt:brocade-lag")
        group_id_key = ET.SubElement(port_channel_redundancy_group, "group-id")
        group_id_key.text = kwargs.pop('group_id')
        activate = ET.SubElement(port_channel_redundancy_group, "activate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import logging
import xml.etree.ElementTree as ET

from ncclient import manager
from ncclient import xml_
import ncclient

import pynos.versions.ver_5.ver_5_0_1.bgp
import pynos.versions.ver_5.ver_5_0_1.snmp
import pynos.versions.ver_5.ver_5_0_1.interface
import pynos.versions.ver_5.ver_5_0_1.lldp
import pynos.versions.ver_5.ver_5_0_1.system
import pynos.versions.ver_5.ver_5_0_1.services
import pynos.versions.ver_6.ver_6_0_1.bgp
import pynos.versions.ver_6.ver_6_0_1.snmp
import pynos.versions.ver_6.ver_6_0_1.interface
import pynos.versions.ver_6.ver_6_0_1.lldp
import pynos.versions.ver_6.ver_6_0_1.system
import pynos.versions.ver_6.ver_6_0_1.services

VERSIONS = {
    '5.0.1': {
        'bgp': pynos.versions.ver_5.ver_5_0_1.bgp.BGP,
        'snmp': pynos.versions.ver_5.ver_5_0_1.snmp.SNMP,
        'interface': pynos.versions.ver_5.ver_5_0_1.interface.Interface,
        'lldp': pynos.versions.ver_5.ver_5_0_1.lldp.LLDP,
        'system': pynos.versions.ver_5.ver_5_0_1.system.System,
        'services': pynos.versions.ver_5.ver_5_0_1.services.Services,
        },
    '6.0.1': {
        'bgp': pynos.versions.ver_6.ver_6_0_1.bgp.BGP,
        'snmp': pynos.versions.ver_6.ver_6_0_1.snmp.SNMP,
        'interface': pynos.versions.ver_6.ver_6_0_1.interface.Interface,
        'lldp': pynos.versions.ver_6.ver_6_0_1.lldp.LLDP,
        'system': pynos.versions.ver_6.ver_6_0_1.system.System,
        'services': pynos.versions.ver_6.ver_6_0_1.services.Services,
        }
    }

NOS_ATTRS = ['bgp', 'snmp', 'interface', 'lldp', 'system', 'services']


class DeviceCommError(Exception):
    """
    Error with device communication.
    """
    pass


class Device(object):
    """
    Device object holds the state for a single NOS device.

    Attributes:
        bgp: BGP related actions and attributes.
        interface: Interface related actions and attributes.
        snmp: SNMP related actions and attributes.
        lldp: LLDP related actions and attributes.
        system: System level actions and attributes.
    """
    def __init__(self, **kwargs):
        """
        Args:
            conn (tuple): IP/Hostname and port of the VDX device you
                intend to connect to. Ex. ('10.0.0.1', '22')
            auth (tuple): Username and password of the VDX device you
                intend to connect to. Ex. ('admin', 'password')
            hostkey_verify (bool): True to verify hostkey, False to bypass
                verify.
            auth_method (string): ```key``` if using ssh-key auth.
                ```userpass``` if using username/password auth.
            auth_key (string): Location of ssh key to use for authentication.

        Returns:
            Instance of the device object.

        Examples:
            >>> from pprint import pprint
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> dev = pynos.device.Device(conn=conn, auth=auth)
            >>> dev.connection
            True
            >>> del dev
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     pprint(dev.mac_table) # doctest: +ELLIPSIS
            [{'interface'...'mac_address'...'state'...'type'...'vlan'...}]
            >>> dev.connection
            False
        """
        self._conn = kwargs.pop('conn')
        self._auth = kwargs.pop('auth', (None, None))
        self._hostkey_verify = kwargs.pop('hostkey_verify', None)
        self._auth_method = kwargs.pop('auth_method', 'userpass')
        self._auth_key = kwargs.pop('auth_key', None)
        self._mgr = None

        self.reconnect()

        ver = self.firmware_version

        for nos_attr in NOS_ATTRS:
            setattr(self, nos_attr, VERSIONS[ver][nos_attr](self._callback))

    def __enter__(self):
        if not self.connection:
            self.reconnect()
        return self

    def __exit__(self, exctype, excisnt, exctb):
        if self.connection:
            self.close()

    @property
    def mac_table(self):
        """list[dict]: the MAC table of the device.
        """
        table = []
        namespace = 'urn:brocade.com:mgmt:brocade-mac-address-table'
        request_mac_table = ET.Element('get-mac-address-table',
                                       xmlns=namespace)
        result = self._callback(request_mac_table, handler='get')
        for entry in result.findall('{%s}mac-address-table' % namespace):
            address = entry.find('{%s}mac-address' % namespace).text
            vlan = entry.find('{%s}vlanid' % namespace).text
            mac_type = entry.find('{%s}mac-type' % namespace).text
            state = entry.find('{%s}mac-state' % namespace).text
            interface = entry.find('{%s}forwarding-interface' % namespace)
            interface_type = interface.find('{%s}interface-type' %
                                            namespace).text
            interface_name = interface.find('{%s}interface-name' %
                                            namespace).text
            interface = '%s%s' % (interface_type, interface_name)

            table.append(dict(mac_address=address, interface=interface,
                              state=state, vlan=vlan,
                              type=mac_type))

        return table

    @property
    def firmware_version(self):
        """
        Returns firmware version.

        Args:
            None

        Returns:
            Dictionary

        Raises:
            None
        """
        namespace = "urn:brocade.com:mgmt:brocade-firmware-ext"

        request_ver = ET.Element("show-firmware-version", xmlns=namespace)

        ver = self._callback(request_ver, handler='get')
        return ver.find('.//*{%s}os-version' % namespace).text

    def _callback(self, call, handler='edit_config', target='running',
                  source='startup'):
        """
        Callback for NETCONF calls.

        Args:
            call: An Element Tree element containing the XML of the NETCONF
                call you intend to make to the device.
            handler: Type of ncclient call to make.
                get: ncclient dispatch. For custom RPCs.
                edit_config: NETCONF standard edit.
                delete_config: NETCONF standard delete.
                copy_config: NETCONF standard copy.
            target: Target configuration location for action. Only used for
                edit_config, delete_config, and copy_config.
            source: Source of configuration information for copying
                configuration. Only used for copy_config.

        Returns:
            None

        Raises:
            None
        """
        try:
            call = ET.tostring(call)
            if handler == 'get':
                call_element = xml_.to_ele(call)
                return ET.fromstring(str(self._mgr.dispatch(call_element)))
            if handler == 'edit_config':
                self._mgr.edit_config(target=target, config=call)
            if handler == 'delete_config':
                self._mgr.delete_config(target=target)
            if handler == 'copy_config':
                self._mgr.copy_config(target=target, source=source)
        except (ncclient.transport.TransportError,
                ncclient.transport.SessionCloseError,
                ncclient.transport.SSHError,
                ncclient.transport.AuthenticationError,
                ncclient.transport.SSHUnknownHostError) as error:
            logging.error(error)
            raise DeviceCommError

    @property
    def connection(self):
        """
        Poll if object is still connected to device in question.

        Args:
            None

        Returns:
            bool: True if connected, False if not.

        Raises:
            None
        """
        return self._mgr.connected

    def reconnect(self):
        """
        Reconnect session with device.

        Args:
            None

        Returns:
            bool: True if reconnect succeeds, False if not.

        Raises:
            None
        """
        if self._auth_method is "userpass":
            self._mgr = manager.connect(host=self._conn[0],
                                        port=self._conn[1],
                                        username=self._auth[0],
                                        password=self._auth[1],
                                        hostkey_verify=self._hostkey_verify)
        elif self._auth_method is "key":
            self._mgr = manager.connect(host=self._conn[0],
                                        port=self._conn[1],
                                        username=self._auth[0],
                                        key_filename=self._auth_key,
                                        hostkey_verify=self._hostkey_verify)
        else:
            raise ValueError("auth_method incorrect value.")
        self._mgr.timeout = 600

        return True

    def find_interface_by_mac(self, **kwargs):
        """Find the interface through which a MAC can be reached.

        Args:
            mac_address (str): A MAC address in 'xx:xx:xx:xx:xx:xx' format.

        Returns:
            list[dict]: a list of mac table data.

        Raises:
            KeyError: if `mac_address` is not specified.

        Examples:
            >>> from pprint import pprint
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     x = dev.find_interface_by_mac(
            ...     mac_address='01:23:45:67:89:ab')
            ...     pprint(x) # doctest: +ELLIPSIS
            [{'interface'...'mac_address'...'state'...'type'...'vlan'...}]
        """
        mac = kwargs.pop('mac_address')
        results = [x for x in self.mac_table if x['mac_address'] == mac]
        return results

    def close(self):
        """Close NETCONF session.

        Args:
            None

        Returns:
            None

        Raises:
            None

        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> dev = pynos.device.Device(conn=conn, auth=auth)
            >>> dev.connection
            True
            >>> dev.close() # doctest: +ELLIPSIS
            <?xml...<rpc-reply...<ok/>...
            >>> dev.connection
            False
        """
        return self._mgr.close_session()



#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_maps_ext(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def maps_get_all_policy_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_all_policy = ET.Element("maps_get_all_policy")
        config = maps_get_all_policy
        input = ET.SubElement(maps_get_all_policy, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_all_policy_output_policy_policyname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_all_policy = ET.Element("maps_get_all_policy")
        config = maps_get_all_policy
        output = ET.SubElement(maps_get_all_policy, "output")
        policy = ET.SubElement(output, "policy")
        policyname = ET.SubElement(policy, "policyname")
        policyname.text = kwargs.pop('policyname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        input = ET.SubElement(maps_get_rules, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_rbridgeid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        rbridgeid = ET.SubElement(rules, "rbridgeid")
        rbridgeid.text = kwargs.pop('rbridgeid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_rulename(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        rulename = ET.SubElement(rules, "rulename")
        rulename.text = kwargs.pop('rulename')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_groupname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        groupname = ET.SubElement(rules, "groupname")
        groupname.text = kwargs.pop('groupname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_monitor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        monitor = ET.SubElement(rules, "monitor")
        monitor.text = kwargs.pop('monitor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_op(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        op = ET.SubElement(rules, "op")
        op.text = kwargs.pop('op')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_value(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        value = ET.SubElement(rules, "value")
        value.text = kwargs.pop('value')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_action(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        action = ET.SubElement(rules, "action")
        action.text = kwargs.pop('action')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_timebase(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        timebase = ET.SubElement(rules, "timebase")
        timebase.text = kwargs.pop('timebase')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_policyname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        policyname = ET.SubElement(rules, "policyname")
        policyname.text = kwargs.pop('policyname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_all_policy_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_all_policy = ET.Element("maps_get_all_policy")
        config = maps_get_all_policy
        input = ET.SubElement(maps_get_all_policy, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_all_policy_output_policy_policyname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_all_policy = ET.Element("maps_get_all_policy")
        config = maps_get_all_policy
        output = ET.SubElement(maps_get_all_policy, "output")
        policy = ET.SubElement(output, "policy")
        policyname = ET.SubElement(policy, "policyname")
        policyname.text = kwargs.pop('policyname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        input = ET.SubElement(maps_get_rules, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_rbridgeid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        rbridgeid = ET.SubElement(rules, "rbridgeid")
        rbridgeid.text = kwargs.pop('rbridgeid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_rulename(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        rulename = ET.SubElement(rules, "rulename")
        rulename.text = kwargs.pop('rulename')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_groupname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        groupname = ET.SubElement(rules, "groupname")
        groupname.text = kwargs.pop('groupname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_monitor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        monitor = ET.SubElement(rules, "monitor")
        monitor.text = kwargs.pop('monitor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_op(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        op = ET.SubElement(rules, "op")
        op.text = kwargs.pop('op')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_value(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        value = ET.SubElement(rules, "value")
        value.text = kwargs.pop('value')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_action(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        action = ET.SubElement(rules, "action")
        action.text = kwargs.pop('action')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_timebase(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        timebase = ET.SubElement(rules, "timebase")
        timebase.text = kwargs.pop('timebase')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def maps_get_rules_output_rules_policyname(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        maps_get_rules = ET.Element("maps_get_rules")
        config = maps_get_rules
        output = ET.SubElement(maps_get_rules, "output")
        rules = ET.SubElement(output, "rules")
        policyname = ET.SubElement(rules, "policyname")
        policyname.text = kwargs.pop('policyname')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import xml.etree.ElementTree as ET


class SNMP(object):
    """
    SNMP class containing all SNMP level methods and attributes.
    """
    def __init__(self, callback):
        """
        SNMP init method.

        Args:
            callback: Callback function that will be called for each action.

        Returns:
            SNMP Object

        Raises:
            None
        """
        self._callback = callback

    def add_snmp_community(self, **kwargs):
        """
        Add SNMP Community to NOS device.

        Args:
            community (str): Community string to be added to device.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `community` is not defined.
        """
        community = kwargs.pop('community')
        callback = kwargs.pop('callback', self._callback)

        config = ET.Element('config')
        snmp_server = ET.SubElement(config, 'snmp-server',
                                    xmlns=("urn:brocade.com:mgmt:"
                                           "brocade-snmp"))
        community_el = ET.SubElement(snmp_server, 'community')
        community_name = ET.SubElement(community_el, 'community')
        community_name.text = community

        return callback(config)

    def del_snmp_community(self, **kwargs):
        """
        Delete SNMP Community from NOS device.

        Args:
            community (str): Community string to be added to device.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `community` is not defined.
        """
        community = kwargs.pop('community')
        callback = kwargs.pop('callback', self._callback)

        config = ET.Element('config')
        snmp_server = ET.SubElement(config, 'snmp-server',
                                    xmlns=("urn:brocade.com:mgmt:"
                                           "brocade-snmp"))
        community_el = ET.SubElement(snmp_server, 'community',
                                     operation='delete')
        community_name = ET.SubElement(community_el, 'community')
        community_name.text = community
        return callback(config)

    def add_snmp_host(self, **kwargs):
        """
        Add SNMP host to NOS device.

        Args:
            host_info (tuple(str, str)): Tuple of host IP and port.
            community (str): Community string to be added to device.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `host_info` or `community` is not defined.
        """
        host_info = kwargs.pop('host_info')
        community = kwargs.pop('community')
        callback = kwargs.pop('callback', self._callback)

        config = ET.Element('config')
        snmp_server = ET.SubElement(config, 'snmp-server',
                                    xmlns=("urn:brocade.com:mgmt:"
                                           "brocade-snmp"))
        host = ET.SubElement(snmp_server, 'host')
        ip_addr = ET.SubElement(host, 'ip')
        ip_addr.text = host_info[0]
        com = ET.SubElement(host, 'community')
        com.text = community
        udp_port = ET.SubElement(host, 'udp-port')
        udp_port.text = host_info[1]
        return callback(config)

    def del_snmp_host(self, **kwargs):
        """
        Delete SNMP host from NOS device.

        Args:
            host_info (tuple(str, str)): Tuple of host IP and port.
            community (str): Community string to be added to device.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `host_info` or `community` is not defined.
        """
        host_info = kwargs.pop('host_info')
        community = kwargs.pop('community')
        callback = kwargs.pop('callback', self._callback)

        config = ET.Element('config')
        snmp_server = ET.SubElement(config, 'snmp-server',
                                    xmlns=("urn:brocade.com:mgmt:"
                                           "brocade-snmp"))
        host = ET.SubElement(snmp_server, 'host', operation='delete')
        ip_addr = ET.SubElement(host, 'ip')
        ip_addr.text = host_info[0]
        com = ET.SubElement(host, 'community')
        com.text = community
        udp_port = ET.SubElement(host, 'udp-port')
        udp_port.text = host_info[1]
        return callback(config)



#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_diagnostics(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def diag_post_rbridge_id_enable(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        diag = ET.SubElement(config, "diag", xmlns="urn:brocade.com:mgmt:brocade-diagnostics")
        post = ET.SubElement(diag, "post")
        rbridge_id = ET.SubElement(post, "rbridge-id")
        rbridge_id_key = ET.SubElement(rbridge_id, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        enable = ET.SubElement(rbridge_id, "enable")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def diag_post_rbridge_id_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        diag = ET.SubElement(config, "diag", xmlns="urn:brocade.com:mgmt:brocade-diagnostics")
        post = ET.SubElement(diag, "post")
        rbridge_id = ET.SubElement(post, "rbridge-id")
        rbridge_id = ET.SubElement(rbridge_id, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def diag_post_enable(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        diag = ET.SubElement(config, "diag", xmlns="urn:brocade.com:mgmt:brocade-diagnostics")
        post = ET.SubElement(diag, "post")
        enable = ET.SubElement(post, "enable")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def diag_post_rbridge_id_enable(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        diag = ET.SubElement(config, "diag", xmlns="urn:brocade.com:mgmt:brocade-diagnostics")
        post = ET.SubElement(diag, "post")
        rbridge_id = ET.SubElement(post, "rbridge-id")
        rbridge_id_key = ET.SubElement(rbridge_id, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        enable = ET.SubElement(rbridge_id, "enable")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def diag_post_rbridge_id_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        diag = ET.SubElement(config, "diag", xmlns="urn:brocade.com:mgmt:brocade-diagnostics")
        post = ET.SubElement(diag, "post")
        rbridge_id = ET.SubElement(post, "rbridge-id")
        rbridge_id = ET.SubElement(rbridge_id, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def diag_post_enable(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        diag = ET.SubElement(config, "diag", xmlns="urn:brocade.com:mgmt:brocade-diagnostics")
        post = ET.SubElement(diag, "post")
        enable = ET.SubElement(post, "enable")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_hardware(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def hardware_connector_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector = ET.SubElement(hardware, "connector")
        name = ET.SubElement(connector, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_sfp_breakout(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector = ET.SubElement(hardware, "connector")
        name_key = ET.SubElement(connector, "name")
        name_key.text = kwargs.pop('name')
        sfp = ET.SubElement(connector, "sfp")
        breakout = ET.SubElement(sfp, "breakout")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_port_group_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        port_group = ET.SubElement(hardware, "port-group")
        name = ET.SubElement(port_group, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_port_group_mode_performance(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        port_group = ET.SubElement(hardware, "port-group")
        name_key = ET.SubElement(port_group, "name")
        name_key.text = kwargs.pop('name')
        mode = ET.SubElement(port_group, "mode")
        performance = ET.SubElement(mode, "performance")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_group_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector_group = ET.SubElement(hardware, "connector-group")
        id = ET.SubElement(connector_group, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_group_speed(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector_group = ET.SubElement(hardware, "connector-group")
        id_key = ET.SubElement(connector_group, "id")
        id_key.text = kwargs.pop('id')
        speed = ET.SubElement(connector_group, "speed")
        speed.text = kwargs.pop('speed')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id = ET.SubElement(flexport, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        type = ET.SubElement(flexport_type, "type")
        type.text = kwargs.pop('type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_instance(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        instance = ET.SubElement(flexport_type, "instance")
        instance.text = kwargs.pop('instance')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_skip_deconfig(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        skip_deconfig = ET.SubElement(flexport_type, "skip_deconfig")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_flexports_output_flexport_list_port_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_flexports = ET.Element("get_flexports")
        config = get_flexports
        output = ET.SubElement(get_flexports, "output")
        flexport_list = ET.SubElement(output, "flexport-list")
        port_id = ET.SubElement(flexport_list, "port-id")
        port_id.text = kwargs.pop('port_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector = ET.SubElement(hardware, "connector")
        name = ET.SubElement(connector, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_sfp_breakout(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector = ET.SubElement(hardware, "connector")
        name_key = ET.SubElement(connector, "name")
        name_key.text = kwargs.pop('name')
        sfp = ET.SubElement(connector, "sfp")
        breakout = ET.SubElement(sfp, "breakout")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_port_group_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        port_group = ET.SubElement(hardware, "port-group")
        name = ET.SubElement(port_group, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_port_group_mode_performance(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        port_group = ET.SubElement(hardware, "port-group")
        name_key = ET.SubElement(port_group, "name")
        name_key.text = kwargs.pop('name')
        mode = ET.SubElement(port_group, "mode")
        performance = ET.SubElement(mode, "performance")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_group_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector_group = ET.SubElement(hardware, "connector-group")
        id = ET.SubElement(connector_group, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_connector_group_speed(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        connector_group = ET.SubElement(hardware, "connector-group")
        id_key = ET.SubElement(connector_group, "id")
        id_key.text = kwargs.pop('id')
        speed = ET.SubElement(connector_group, "speed")
        speed.text = kwargs.pop('speed')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id = ET.SubElement(flexport, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        type = ET.SubElement(flexport_type, "type")
        type.text = kwargs.pop('type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_instance(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        instance = ET.SubElement(flexport_type, "instance")
        instance.text = kwargs.pop('instance')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hardware_flexport_flexport_type_skip_deconfig(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hardware = ET.SubElement(config, "hardware", xmlns="urn:brocade.com:mgmt:brocade-hardware")
        flexport = ET.SubElement(hardware, "flexport")
        id_key = ET.SubElement(flexport, "id")
        id_key.text = kwargs.pop('id')
        flexport_type = ET.SubElement(flexport, "flexport_type")
        skip_deconfig = ET.SubElement(flexport_type, "skip_deconfig")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_flexports_output_flexport_list_port_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_flexports = ET.Element("get_flexports")
        config = get_flexports
        output = ET.SubElement(get_flexports, "output")
        flexport_list = ET.SubElement(output, "flexport-list")
        port_id = ET.SubElement(flexport_list, "port-id")
        port_id.text = kwargs.pop('port_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import xml.etree.ElementTree as ET
from pynos.versions.base.yang.brocade_rbridge import brocade_rbridge
import pynos.utilities


class System(object):
    """
    System class containing all system level methods and attributes.
    """
    def __init__(self, callback):
        """System init method.

        Args:
            callback: Callback function that will be called for each action.

        Returns:
            System Object

        Raises:
            None
        """
        self._callback = callback
        self._rbridge = brocade_rbridge(callback=pynos.utilities.return_xml)

    @property
    def uptime(self):
        """dict: device uptime
        """
        namespace = 'urn:brocade.com:mgmt:brocade-system'
        get_system_uptime = ET.Element('get-system-uptime', xmlns=namespace)
        results = self._callback(get_system_uptime, handler='get')
        system_uptime = dict(days=results.find('.//{%s}days' % namespace).text,
                             hours=results.find('.//{%s}hours' %
                                                namespace).text,
                             minutes=results.find('.//{%s}minutes' %
                                                  namespace).text,
                             seconds=results.find('.//{%s}seconds' %
                                                  namespace).text)
        return system_uptime

    def router_id(self, **kwargs):
        """Configures device's Router ID.

        Args:
            router_id (str): Router ID for the device.
            rbridge_id (str): The rbridge ID of the device on which BGP will be
                configured in a VCS fabric.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `router_id` is not specified.

        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.system.router_id(router_id='10.24.39.211',
            ...     rbridge_id='225')
            ...     dev.system.router_id() # doctest: +IGNORE_EXCEPTION_DETAIL
            Traceback (most recent call last):
            KeyError
        """
        router_id = kwargs.pop('router_id')
        rbridge_id = kwargs.pop('rbridge_id', '1')
        callback = kwargs.pop('callback', self._callback)
        rid_args = dict(rbridge_id=rbridge_id, router_id=router_id)
        config = self._rbridge.rbridge_id_ip_rtm_config_router_id(**rid_args)
        return callback(config)
